@@ -178,7 +178,7 @@ def multiline_prompt(
         kb.add("enter")(submit)
 
     # Define key bindings for undo and redo
-    @kb.add("control-z")
+    @kb.add("c-z")
     def undo(event: KeyPressEvent):
         """
         Undo the last user message.
